@@ -122,9 +122,9 @@ class ElementKeywords(LibraryContext):
           you know how deep (0 means root) in the tree you are and on what position
           (1-indexed) the child you're looking for is.
         - The returned structure is a dictionary with all the children flattened per
-          depth level. Additionally, these `WindowsElement`s contain a relevant locator
-          composed of "root > path" which will work to identify the element in the
-          tree.
+          depth level. Additionally, these `WindowsElement` objects contain a relevant
+          locator composed of "root > path" which will help to identify the element in
+          the tree.
 
         Portal example:
         https://robocorp.com/portal/robot/robocorp/example-windows-element-path
